@@ -1,3 +1,3 @@
 allowed_elements <- c("pre-exercise-code", "sample-code", "solution", "sct", "hint")
-required_elements <- c("sample-code", "solution", "sct")
+required_elements <- c("sample-code")
 project_alias <- "DataCamp Light"
