@@ -8,7 +8,7 @@ register_vignette_engines <- function(pkg) {
 
 #' @importFrom knitr knit_filter
 vig_engine <- function(..., tangle = knitr:::vtangle) {
-  knitr:::vig_engine0(..., tangle = tangle, package = "tutorial", aspell = list(
+  tools::vignetteEngine(..., tangle = tangle, package = "tutorial", aspell = list(
     filter = knit_filter
   ))
 }
